@@ -10,21 +10,24 @@ load_dotenv()
 # Initialize Flask app
 app = Flask(__name__)
 
-# Database configuration
+# Configurations
 app.config['SECRET_KEY'] = os.getenv('SECRET_KEY', 'default-secret-key')
 app.config['SQLALCHEMY_DATABASE_URI'] = os.getenv('DATABASE_URL', 'sqlite:///app.db')
 app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
 
-# Initialize extensions
+# Initialize Extensions
 db = SQLAlchemy(app)
 migrate = Migrate(app, db)
 
-# Import routes after db initialization
-from app.routes.api import bp as api_bp
-app.register_blueprint(api_bp, url_prefix='/api')
+# Import Models and Routes (Ensure these files exist)
+from app import routes, models
 
-# Import models to ensure they're registered with SQLAlchemy
-from app.models import Product, Supplier
+# Default Route (Health Check)
+@app.route('/health')
+def health_check():
+    return {"status": "healthy"}
 
+# Run App (for development purposes)
 if __name__ == '__main__':
     app.run(debug=True)
+
